@@ -1,6 +1,6 @@
 package VM::JiffyBox::Box;
 {
-  $VM::JiffyBox::Box::VERSION = '0.006'; # TRIAL
+  $VM::JiffyBox::Box::VERSION = '0.007'; # TRIAL
 }
 
 # ABSTRACT: Representation of a Virtual Machine in JiffyBox
@@ -9,9 +9,7 @@ use Moo;
 use JSON;
 use LWP::UserAgent; # needed?
 
-my $def = sub {die unless $_[0]};
-
-has id         => (is => 'ro', isa => $def);
+has id         => (is => 'rw', required => 1);
 has hypervisor => (is => 'rw');
 
 has last          => (is => 'rw');
@@ -170,25 +168,123 @@ VM::JiffyBox::Box - Representation of a Virtual Machine in JiffyBox
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
-See the C<examples> directory for examples of working code.
-Synopsis will come when first stable release is here.
+This module should be used together with L<VM::JiffyBox>.
+L<VM::JiffyBox> is the factory for producing objects of this module.
+However if you want to do it yourself:
+
+ my $box = VM::JiffyBox::Box->new(id => $box_id);
+
+ # set the hypervisor of the VM (e.g. ref to JiffyBox)
+ $box->hypervisor($ref);
+
+You then can do a lot of stuff with this box:
+
+ # get some info
+ my $backup_id  = $box->get_backups()->{result}->{daily}->{id};
+ my $plan_id    = $box->get_details()->{result}->{plan}->{id};
+
+ # get more info using the caching technique
+ my $state      = $box->last->{result}->{status}
+ # ... or
+ use Data::Dumper;
+ print Dumper( $box->backup_cache->{result} );
+
+ # start, stop, delete...
+ if ( $box->start ) {
+     print "VM started"
+ }
+
+ # and so on...
+
+(See also the SYNOPSIS of L<VM::JiffyBox> or the C<examples> directory for more examples of working code.)
 
 =encoding utf8
 
-=head1 PLEASE NOTE
+=head1 ERROR HANDLING
 
-This module ist still under heavy development and a B<TRIAL> release.
-We do not recommend to use it.
+All methods will return C<0> on failure, so you can check for this with a simple C<if> on the return value.
+If you need the error message you can use the cache and look into the attribute C<last>.
+The form of the message is open.
+It can contain a simple string, or also a hash.
+This depends on the kind of error.
+So if you want to be sure, just use L<Data::Dumper> to print it.
+
+=head1 CACHING
+
+There are possibilities to take advantage of caching functionality.
+The following caches are available:
+
+=over
+
+=item last
+
+Always contains the last information.
+
+=item backup_cache 
+
+Contains information of the last call to get_backups().
+
+=item details_cache
+
+Contains information of the last call to get_details().
+
+=item start_cache
+
+Contains information of the last call to start().
+
+=item stop_cache
+
+Contains information of the last call to stop().
+
+=item delete_cache
+
+Contains information of the last call to delete().
+
+=back
+
+=head1 METHODS
+
+=head2 get_details
+
+Returns hashref with information about the virtual machine.
+Takes no arguments.
+
+=head2 get_backups
+
+Returns hashref with information about the backups of the virtual machine.
+Takes no arguments.
+
+=head2 start
+
+Starts a virtual machine.
+It must be ensured (by you) that the machine has the state C<READY> before calling this.
+
+=head2 stop
+
+Stop a virtual machine.
+
+=head2 delete
+
+Delete a virtual machine.
+(Be sure that the VM has the appropriate state for doing so)
 
 =head1 SEE ALSO
 
 =over
 
-=item * L<https://github.com/tim-schwarz/VM-JiffyBox>
+=item *
+
+Source, contributions, patches: L<https://github.com/tim-schwarz/VM-JiffyBox>
+
+=item *
+
+This module is B<not> officially supported by or related to the company I<domainfactory> in Germany.
+However it aims to provide an interface to the API of their product I<JiffyBox>.
+So to use this module with success you should also B<read their API-Documentation>, available for registered users of their service.
 
 =back
 
